Module iter

Module iter 

Iterating over entities and queries.

Traits

LendingIterator
A trait similar to Iterator, where the returned Items only live until next is called again.
Lifetime
Provides the associated item for LendingIterator, similar to Iterator::Item.

Type Aliases

Iter
An iterator over a slice that copies its values.